/* IMPORTANT:
 * special compiler instructions: set Assume SS=DS to Never
 * (in Options > Compiler > Code generation)
 */

/* seti.c -- ONI 2002 problem
 * problem and official solution by Mihai Patrascu
 */
#pragma option -3 -r -Z -O2 -a -h- -N-
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <ctype.h>

#define MAX_WORD	16

/* 512 input lines per pool line */
char huge datapool[4][32768u];

char _ds *huge sortpool[4][32768u];
char _ds *huge tmp_pool[32768u];

char buf[32768u];
char s[100];

#if 0
#define my_assert(cond)		((cond) ? (void) 0 : (_DS = _SS, abort()))
#else
#define my_assert(cond)		((void) 0)
#endif

#define achr	((char _ds *) 0)
#define aptr	((char _ds * _es *) 0)
#define atmp	((char _ds * _ds *) 0)
#define abuf	((char _ss *) buf)

void do_preproc(unsigned n, unsigned ds_achr, unsigned ds_atmp)
{
	unsigned i, j, cnt[256];

	for(i = 0; i < n; i++)
		aptr[i] = achr + i;
	for(i = MAX_WORD; i--; ) {
		/* must prevent BC optimizations; now, ain't this ironical? */
		*cnt = 0;
		for(j = 1; j < 256; j++)
			cnt[j] = cnt[j - 1];

		_DS = ds_achr;
		for(j = 0; j < n; j++)
			cnt[abuf[j] = aptr[j][i]]++;
		my_assert(_DS == ds_achr);

		for(j = 0; j < 255; j++)
			cnt[j + 1] += cnt[j];
		for(j = 255; j; j--)
			cnt[j] = cnt[j - 1];
		*cnt = 0;

		_DS = ds_atmp;
		for(j = 0; j < n; j++)
			atmp[j] = aptr[j];
		for(j = 0; j < n; j++)
			aptr[cnt[abuf[j]]++] = atmp[j];
		my_assert(_DS == ds_atmp);
	}
}

#undef achr
#undef aptr
#undef atmp
#undef abuf

void preproc(int line, unsigned n)
{
	union {
		void far *p;
		unsigned b[2];
	} ds1, ds2, newes;

	ds1.p = datapool[line];
	ds2.p = tmp_pool;
	newes.p = sortpool[line];
	my_assert(!newes.b[0] && !ds1.b[0] && !ds2.b[0]);
	my_assert(_DS == _SS);

	_ES = newes.b[1];
	do_preproc(n, ds1.b[1], ds2.b[1]);
	my_assert(_ES == newes.b[1]);
	_DS = _SS;
}

#define achr	((char _ds *) 0)
#define aptr	((char _ds * _es *) 0)

#define X(i, x) \
	if(s1[i] == s2[i]) { x } \
	else return(s1[i] > s2[i]);

int ge(char _ss *s1, char _ds *s2)
{
	X(0, X(1, X(2, X(3, X(4, X(5, X(6, X(7,	X(8, X(9, X(10, X(11,
		X(12, X(13, X(14, X(15, X(16,
			my_assert(0);
			return(0);	/* avoid warning */
		)))))))))))))))))
}

unsigned do_query(unsigned n)
{
	unsigned i = 0, inc;

	for(inc = 0x8000; inc; inc >>= 1)
		if((i + inc <= n) && ge((char _ss *) s, aptr[i + inc - 1]))
			i += inc;
	return(i);
}

#undef achr
#undef aptr
#undef s

unsigned query(int line, unsigned n)
{
	union {
		void far *p;
		unsigned b[2];
	} newds, newes;
	unsigned res;

	newds.p = datapool[line];
	newes.p = sortpool[line];
	my_assert(!newes.b[0] && !newds.b[0]);
	my_assert(_DS == _SS);

	_ES = newes.b[1];
	_DS = newds.b[1];
	res = do_query(n);
	my_assert((_ES == newes.b[1]) && (_DS == newds.b[1]));
	_DS = _SS;
	return(res);
}

int main()
{
	FILE *f;
	int n, i, m;

	f = fopen("seti.in", "r");
	setvbuf(f, buf, _IOFBF, 0x4000);
	fscanf(f, "%d ", &n);
	for(i = 0; i < n; i++) {
		fgets(s, sizeof(s), f);
		_fmemcpy(datapool[i >> 9] + ((i & 511) << 6), s, 64);
	}
	fclose(f);

	_fmemset(datapool[n >> 9] + ((n & 511) << 6), '.', 64);
	for(i = 0; i < n; i += 512) {
		if(i + 512 <= n)
			preproc(i >> 9, 32768u);
		else preproc(i >> 9, (n - i) << 6);
	}

	freopen("dic.in", "r", stdin);
	freopen("seti.out", "w", stdout);
	setvbuf(stdin, buf, _IOFBF, 0x4000);
	setvbuf(stdout, buf + 0x4000, _IOFBF, 0x4000);
	for(scanf("%d ", &m); m--; ) {
		long res = 0;
		int l;

		gets(s);
		l = strlen(s);

		for(i = l; i <= MAX_WORD; s[i++] = 0) ;
		for(i = 0; i < n; i += 512) {
			if(i + 512 <= n)
				res -= query(i >> 9, 32768u);
			else res -= query(i >> 9, (n - i) << 6);
		}

		for(i = l; i <= MAX_WORD; s[i++] = 127) ;
		for(i = 0; i < n; i += 512) {
			if(i + 512 <= n)
				res += query(i >> 9, 32768u);
			else res += query(i >> 9, (n - i) << 6);
		}
		printf("%ld\n", res);
	}
	return(0);
}
